<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="HF编码">
              <j-input placeholder="请输入HF编码" v-model="queryParam.hfCode"></j-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="模板名称">
              <j-input placeholder="请输入模板名称" v-model="queryParam.hfName"></j-input>
            </a-form-item>
          </a-col>
          <a-col :xl="4" :lg="7" :md="8" :sm="24">
            <a-form-item label="模板分类">
              <j-dict-select-tag dict-code="hf_template_category" placeholder="请选择模板分类"
                                 v-model="queryParam.hfCategory"></j-dict-select-tag>
            </a-form-item>
          </a-col>
          <a-col :xl="4" :lg="7" :md="8" :sm="24">
            <a-form-item label="状态">
              <j-dict-select-tag dict-code="enable_disable" placeholder="请选择状态"
                                 v-model="queryParam.hfStatus"></j-dict-select-tag>
            </a-form-item>
          </a-col>

          <a-col :xl="4" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="info" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel">
            <a-icon type="delete" />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作
          <a-icon type="down" />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a
        style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)" v-if="record.hfStatus === 'ENABLE'">编辑</a>
          <a-divider type="vertical" v-if="record.hfStatus === 'ENABLE'" />
          <a @click="handleUpgrade(record)" v-if="record.hfStatus === 'ENABLE'">升版</a>
          <a-divider type="vertical" v-if="record.hfStatus === 'ENABLE'" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamBaseHFCode-modal ref="modalForm" @ok="modalFormOk"></eamBaseHFCode-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import EamBaseHFCodeModal from './modules/EamBaseHFCodeModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'

export default {
  name: 'EamBaseHFCodeList',
  mixins: [JeecgListMixin],
  components: {
    EamBaseHFCodeModal
  },
  data() {
    return {
      description: 'HFCode维护管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: 'HF编码',
          align: 'center',
          dataIndex: 'hfCode'
        },
        {
          title: '模板名称',
          align: 'center',
          dataIndex: 'hfName'
        },
        {
          title: '模板分类',
          align: 'center',
          dataIndex: 'hfCategory_dictText'
        },
        {
          title: '状态',
          align: 'center',
          dataIndex: 'hfStatus_dictText'
        },
        {
          title: '版本',
          align: 'center',
          dataIndex: 'hfVersion'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/eamBaseHFCode/list',
        delete: '/eam/eamBaseHFCode/delete',
        deleteBatch: '/eam/eamBaseHFCode/deleteBatch'
      }
    }
  },
  computed: {},
  methods: {
    handleUpgrade(record) {
      //升版
      this.$refs.modalForm.upgrade(record);
      this.$refs.modalForm.title = "升版";
      this.$refs.modalForm.disableSubmit = false;
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>